Index: fetch_configs/dartino.py |
diff --git a/fetch_configs/fletch.py b/fetch_configs/dartino.py |
similarity index 80% |
rename from fetch_configs/fletch.py |
rename to fetch_configs/dartino.py |
index 071d5923144ccb4feb8dd89cd5a22a0f63ba80bb..cd74804ae7bce8e49f3abcb6bd6c8318cb454415 100644 |
--- a/fetch_configs/fletch.py |
+++ b/fetch_configs/dartino.py |
@@ -8,14 +8,14 @@ import config_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class Fletch(config_util.Config): |
- """Basic Config class for Fletch.""" |
+class Dartino(config_util.Config): |
+ """Basic Config class for Dartino.""" |
@staticmethod |
def fetch_spec(props): |
- url = 'https://github.com/dart-lang/fletch.git' |
+ url = 'https://github.com/dartino/sdk.git' |
solution = { |
- 'name' :'fletch', |
+ 'name' :'sdk', |
'url' : url, |
'deps_file': 'DEPS', |
'managed' : False, |
@@ -34,11 +34,11 @@ class Fletch(config_util.Config): |
@staticmethod |
def expected_root(_props): |
- return 'fletch' |
+ return 'sdk' |
def main(argv=None): |
- return Fletch().handle_args(argv) |
+ return Dartino().handle_args(argv) |
if __name__ == '__main__': |